pub async fn probe_evm_version<N: Network, P: Provider<N>>(
provider: &P,
block: BlockId,
) -> Option<EvmVersion>Expand description
Returns the newest EVM version whose features, and those of every earlier probed version, the
node executes at block.
Returns None if the node rejects the probe call or returns an unexpected result.